<?php //###
//Acoustic template file,
//MP Audio Store plugin & Acoustic Theme
//created June 2013, Jonathan Potter, PotterVilla Applied Technology.
//http://pottervilla.com
//Version: 0.3.0
?>

<?php /*If you have any custom code from your theme, it'll need to go way at the bottom, past the functions. See you down there...*/
<?php
function mp_list_products_custom( $echo = true, $paginate = '', $page = '', $per_page = '', $order_by = '', $order = '', $category = '', $tag = '', $list_view = NULL ) {
  global $wp_query, $mp;

  //setup taxonomy if applicable
  if ($category) {
    $taxonomy_query = '&product_category=' . sanitize_title($category);
  } else if ($tag) {
    $taxonomy_query = '&product_tag=' . sanitize_title($tag);
  } else if (isset($wp_query->query_vars['taxonomy']) && ($wp_query->query_vars['taxonomy'] == 'product_category' || $wp_query->query_vars['taxonomy'] == 'product_tag')) {
    //TODO might need to fix for tags that are a number
    $taxonomy_query = '&' . $wp_query->query_vars['taxonomy'] . '=' . $wp_query->query_vars['term'];
  } else {
    $taxonomy_query = '';
  }

  //setup pagination
  $paged = false;
  if ($paginate) {
    $paged = true;
  } else if ($paginate === '') {
    if ($mp->get_setting('paginate'))
      $paged = true;
    else
      $paginate_query = '&nopaging=true';
  } else {
    $paginate_query = '&nopaging=true';
  }

  //get page details
  if ($paged) {
    //figure out perpage
    if (intval($per_page)) {
      $paginate_query = '&posts_per_page='.intval($per_page);
    } else {
      $paginate_query = '&posts_per_page='.$mp->get_setting('per_page');
		}

    //figure out page
    if (isset($wp_query->query_vars['paged']) && $wp_query->query_vars['paged'])
      $paginate_query .= '&paged='.intval($wp_query->query_vars['paged']);

    if (intval($page))
      $paginate_query .= '&paged='.intval($page);
    else if ($wp_query->query_vars['paged'])
      $paginate_query .= '&paged='.intval($wp_query->query_vars['paged']);
  }

  //get order by
  if (!$order_by) {
    if ($mp->get_setting('order_by') == 'price')
      $order_by_query = '&meta_key=mp_price_sort&orderby=meta_value_num';
    else if ($mp->get_setting('order_by') == 'sales')
      $order_by_query = '&meta_key=mp_sales_count&orderby=meta_value_num';
    else
      $order_by_query = '&orderby='.$mp->get_setting('order_by');
  } else {
  	if ('price' == $order_by)
  		$order_by_query = '&meta_key=mp_price_sort&orderby=meta_value_num';
    else if('sales' == $order_by)
      $order_by_query = '&meta_key=mp_sales_count&orderby=meta_value_num';
    else
    	$order_by_query = '&orderby='.$order_by;
  }

  //get order direction
  if (!$order) {
    $order_query = '&order='.$mp->get_setting('order');
  } else {
    $order_query = '&order='.$order;
  }

  //The Query
  $custom_query = new WP_Query('post_type=product&post_status=publish' . $taxonomy_query . $paginate_query . $order_by_query . $order_query);

  //allows pagination links to work get_posts_nav_link()
  if ($wp_query->max_num_pages == 0 || $taxonomy_query)
    $wp_query->max_num_pages = $custom_query->max_num_pages;

  // get layout type for products
  if ( is_null($list_view) ) {
    $layout_type = $mp->get_setting('list_view');
  } else {
    $layout_type = $list_view ? 'list' : 'grid';
  }

  $content = '<div id="mp_product_list" class="mp_'.$layout_type.'">';

  if ($last = $custom_query->post_count) {

		$content .= $layout_type == 'grid' ?
									_mp_products_html_grid_custom($custom_query->posts) :
									_mp_products_html_list_custom($custom_query->posts);

  } else {
    $content .= '<div id="mp_no_products">' . apply_filters( 'mp_product_list_none', __('No Products', 'mp') ) . '</div>';
  }

  $content .= '</div>';

  if ($echo)
    echo $content;
  else
    return $content;
}

function _mp_products_html_grid_custom($post_array=array()){
  global $mp;
  $html='';

  //get image width
  if ($mp->get_setting('list_img_size') == 'custom'){
    $width = $mp->get_setting('list_img_width');
  } else {
    $size = $mp->get_setting('list_img_size');
    $width = get_option($size."_size_w");
  }

  $inline_style = !( $mp->get_setting('store_theme') == 'none' || current_theme_supports('mp_style') );

  foreach ($post_array as $post) {

    $img = mp_product_image(false, 'list', $post->ID);
    $excerpt = $mp->get_setting('show_excerpt') ?
                      '<p class="mp_excerpt">'.$mp->product_excerpt($post->post_excerpt, $post->post_content, $post->ID, '').'</p>' :
                      '';
    $mp_product_list_content = apply_filters( 'mp_product_list_content', $excerpt, $post->ID );

    $class=array();
    $class[] = strlen($img)>0?'mp_thumbnail':'';
    $class[] = strlen($excerpt)>0?'mp_excerpt':'';
    $class[] = mp_has_variations($post->ID) ? 'mp_price_variations':'';

    $html .= '<div class="mp_one_tile '.implode($class, ' ').'">
                <div class="mp_one_product mp_squeeze_block"' . ($inline_style ? ' style="width: '.$width.'px;"' : '') . '>

                  <div class="mp_product_detail mp_squeeze_block"' . ($inline_style ? ' style="width: '.$width.'px;"' : '') . '>
					<div class="mp_squeeze_image">
                    '.$img.'
					</div>
					<div class="mp_squeeze_text">
                    <h3 class="mp_product_name">
                      <a href="' . get_permalink( $post->ID ) . '">' . $post->post_title . '</a>
                    </h3>

                    '.$mp_product_list_content.'
					</div>
					<div style="float: right; margin-right: 10px;">
					<div class="mp_squeeze">
					
					<span class="mp3-label">'.get_post_meta($post->ID, 'acoustics_media_short', True).'</span>&nbsp;
                    <span class="mp3-label">'.mp_product_price(false, $post->ID, false).'</span><span style="padding-right: 7px;"></span></div>
                    '.mp_buy_button(false, 'list', $post->ID).'
                    '.apply_filters( 'mp_product_list_meta', '', $post->ID ).'
</div></div>
                </div>
              </div>';

  }

  $html .= (count($post_array)>0?'<div class="clear"></div>':'');

  return $html;
}

function _mp_products_html_list_custom($post_array=array()){
  global $mp;
  $html='';
  $total = count($post_array);
  $count = 0;
  foreach($post_array as $post){
      $count++;

      //add last css class for styling grids
      if ($count == $total)
          $class = array('mp_product', 'last-product');
      else
          $class = 'mp_product';

      $html .= '<div '.mp_product_class(false, $class, $post->ID).' style="clear: both;">';
      $html .= '<h3 class="mp_product_name"><a href="' . get_permalink( $post->ID ) . '">' . $post->post_title . '</a></h3>';
      $html .= '<div class="mp_product_content">';
      $product_content = mp_product_image( false, 'list', $post->ID );
      if ($mp->get_setting('show_excerpt'))
          $product_content .= $mp->product_excerpt($post->post_excerpt, $post->post_content, $post->ID);
      $html .= apply_filters( 'mp_product_list_content', $product_content, $post->ID );
      $html .= '</div>';

      $html .= '<div class="mp_product_meta">';
      //price
      $meta = mp_product_price(false, $post->ID);
      //button
      $meta .= mp_buy_button(false, 'list', $post->ID);
      $html .= apply_filters( 'mp_product_list_meta', $meta, $post->ID );
      $html .= '</div>';

      $html .= '</div>';
  }

  return $html;
}

?>
/*Here's where your custom theme code goes:*/
<?php get_header(); ?>
<div id="container">
/*Just leave this line alone:*/
<?php mp_list_products_custom(true);?>
/*And pickup here again!*/
</div><!-- #container -->


<?php get_footer(); ?>